@@ -32,6 +32,7 @@
 #include <QString>
 #include <QTabWidget>
 #include <QPointer>
+#include <QHash>
 
 // include files for KDE
 #include <KGlobalAccel>
@@ -296,9 +297,6 @@ void KMixWindow::initWidgets()
 	m_wsMixers->setTabsClosable(false);
 	connect(m_wsMixers, SIGNAL(tabCloseRequested(int)), SLOT(saveAndCloseView(int)));
 
-	QPixmap cornerNewPM = KIconLoader::global()->loadIcon("tab-new", KIconLoader::Toolbar,
-			IconSize(KIconLoader::Small));
-
 	connect(m_wsMixers, SIGNAL(currentChanged(int)), SLOT(newMixerShown(int)));
 
 	// show menubar if the actions says so (or if the action does not exist)
@@ -546,7 +544,7 @@ void KMixWindow::loadBaseConfig()
 /**
  * Loads the volumes of all mixers from kmixctrlrc.
  * In other words:
- * Restores the default voumes as stored via saveVolumes() or the
+ * Restores the default volumes as stored via saveVolumes() or the
  * execution of "kmixctrl --save"
  */
 
@@ -596,7 +594,7 @@ void KMixWindow::recreateGUI(bool saveConfig, const QString& mixerId, bool force
 		saveViewConfig();  // save the state before recreating
 
 	// -2- RECREATE THE ALREADY EXISTING TABS **********************************
-	QMap<Mixer*, bool> mixerHasProfile;
+	QHash<Mixer*, bool> mixerHasProfile;
 
 // -2a- Build a list of all active profiles in the main window (that means: from all tabs)
 	QList<GUIProfile*> activeGuiProfiles;
@@ -754,7 +752,7 @@ void KMixWindow::recreateGUI(bool saveConfig, const QString& mixerId, bool force
 		bool dockingSucceded = updateDocking();
 		if (!dockingSucceded && !Mixer::mixers().empty())
 		{
-			show(); // avoid invisible and unaccessible main window
+			show(); // avoid invisible and inaccessible main window
 		}
 	}
 	else
@@ -957,7 +955,7 @@ void KMixWindow::unplugged(const QString& udi)
  * This widget shows an error message like "no mixers detected.
  void KMixWindow::setErrorMixerWidget()
  {
- QString s = i18n("Please plug in your soundcard.No soundcard found. Probably you have not set it up or are missing soundcard drivers. Please check your operating system manual for installing your soundcard."); // !! better text
+ QString s = i18n("Please plug in your soundcard. No soundcard found. Probably you have not set it up or are missing soundcard drivers. Please check your operating system manual for installing your soundcard."); // !! better text
  m_errorLabel = new QLabel( s,this  );
  m_errorLabel->setAlignment( Qt::AlignCenter );
  m_errorLabel->setWordWrap(true);
@@ -1031,7 +1029,7 @@ bool KMixWindow::addMixerWidget(const QString& mixer_ID, QString guiprofId, int
 
 	kmw->loadConfig(KSharedConfig::openConfig().data());
 	// Now force to read for new tabs, especially after hotplug. Note: Doing it here is bad design and possibly
-	// obsolete, as the backend should take care of upating itself.
+	// obsolete, as the backend should take care of updating itself.
 	kmw->mixer()->readSetFromHWforceUpdate();
 	return true;
 }
@@ -1175,7 +1173,7 @@ void KMixWindow::showAbout()
 
 /**
  * Apply the Preferences from the preferences dialog. Depending on what has been changed,
- * the corresponding announcemnts are made.
+ * the corresponding announcements are made.
  */
 void KMixWindow::applyPrefs()
 {
